@@ -23,12 +23,8 @@
 #include "config.h"
 #include <gnome.h>
 
-#ifdef USING_OAF
-#include <liboaf/liboaf.h>
-#include <bonobo.h>
-#else
-#include <libgnorba/gnorba.h>
-#endif
+#include <bonobo-activation/bonobo-activation.h>
+#include <libbonobo.h>
 
 #include "orbit_daemon_glue.h"
 #include "queue_io.h"
@@ -236,8 +232,11 @@ get_client_id(const GNOME_Pilot_Client cb)
 }
 
 
+
+/********************************************************************************/
+
 static void
-pause_device(GPilotDevice *device,gpointer data)
+gpilotd_corba_pause_device(GPilotDevice *device,gpointer data)
 {
 	if (device->io) {
 		g_source_remove(device->in_handle);
@@ -245,22 +244,39 @@ pause_device(GPilotDevice *device,gpointer data)
 	}
 }
 
-/********************************************************************************/
+static void
+gpilotd_corba_pause_notify_monitor (gchar* key,
+				    GSList **value,
+				    CORBA_boolean *on_off) 
+{	
+	GNOME_Pilot_Client cb = CORBA_ORB_string_to_object(orb, (CORBA_char*)key, &ev);
+	GNOME_Pilot_Client_pause (cb, *on_off, &ev);
+
+	if (ev._major != CORBA_NO_EXCEPTION) {
+		char *client_id = get_client_id (cb);
+		g_message ("corba: monitor %.20s dead", client_id);
+		CORBA_exception_free (&ev);
+		CORBA_free (client_id);
+	}	
+}
 
 static void
 gpilotd_corba_pause(GNOME_Pilot_Daemon obj,
 		    CORBA_boolean on_off,
 		    CORBA_Environment *ev)  
 {
-	g_message("corba: gpilotd_corba_pause(%s)",on_off==TRUE?"true":"false");
 	if (orb_context->gpilotd_context->paused == on_off) return;
 
 	orb_context->gpilotd_context->paused = on_off;
 
+	g_hash_table_foreach (orb_context->monitors,
+			      (GHFunc)gpilotd_corba_pause_notify_monitor,
+			      &on_off);
+
 	if (orb_context->gpilotd_context->paused) {
 		g_list_foreach(orb_context->gpilotd_context->devices,
-			      (GFunc)pause_device,
-			       NULL);
+			      (GFunc)gpilotd_corba_pause_device,
+			       NULL);				      
 	} else {
 		kill(getpid(),SIGHUP);
 	}
@@ -268,6 +284,17 @@ gpilotd_corba_pause(GNOME_Pilot_Daemon obj,
 	return;
 }
 
+/********************************************************************************/
+
+static void
+gpilotd_corba_noop (GNOME_Pilot_Daemon obj,
+		    CORBA_Environment *ev)
+{
+	return;
+}
+
+/********************************************************************************/
+
 static CORBA_unsigned_long
 gpilotd_corba_request_install(GNOME_Pilot_Daemon obj,
 			      const GNOME_Pilot_Client cb,
@@ -353,17 +380,17 @@ gpilotd_corba_request_restore(GNOME_Pilot_Daemon obj,
 		g_free(directory);
 		gpthrow_with_settings(UnknownPilot,0,exn,exn->pilotId = CORBA_string_dup(pilot_name));
 	}
-	if(stat(directory,&statbuf)==-1) {
-		g_free(client_id);
-		g_free(directory);
+	if (stat (directory, &statbuf)==-1) {
+		g_free (client_id);
+		g_free (directory);
 
-		gpthrow(MissingFile,0);
+		gpthrow (MissingFile,0);
 	}
-	if(S_ISDIR(statbuf.st_mode) && access(directory,R_OK)!=0) {
-		g_free(client_id);
-		g_free(directory);
-		g_message("or here access=%d, S_ISDIR=%d",access(directory,R_OK),S_ISDIR(statbuf.st_mode));
-		gpthrow(MissingFile,0);
+	if (S_ISDIR (statbuf.st_mode) && access (directory,R_OK)!=0) {
+		g_free (client_id);
+		g_free (directory);
+		g_message ("or here access=%d, S_ISDIR=%d", access(directory,R_OK), S_ISDIR(statbuf.st_mode));
+		gpthrow (MissingFile, 0);
 	}
 	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
 	req.cradle = NULL;
@@ -496,15 +523,15 @@ gpilotd_corba_get_system_info(GNOME_Pilot_Daemon obj,
 static CORBA_unsigned_long
 gpilotd_corba_set_user_info(GNOME_Pilot_Daemon obj,
 			    const GNOME_Pilot_Client cb,
-			    GNOME_Pilot_PilotUser *user,
+			    GNOME_Pilot_UserInfo *user,
 			    const CORBA_char *cradle, 
 			    const CORBA_boolean continue_sync,
 			    const GNOME_Pilot_Survival survival,
 			    const CORBA_unsigned_long timeout, 
 			    CORBA_Environment *ev) 
 {
-	GPilotRequest req;
 	gchar *client_id;
+	int result;
 
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 
@@ -515,25 +542,23 @@ gpilotd_corba_set_user_info(GNOME_Pilot_Daemon obj,
 	LOG("corba:               user    = %s)",user->username);
 	/*LOG("corba:               password= %s)",user->password);*/
 	/* FIXME: check for cradle existance, throw exn if not */
-	req.type = GREQ_SET_USERINFO;
-	req.pilot_id = 0;
-	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.cradle = g_strdup(cradle);
-	req.client_id = g_strdup(client_id);
-	req.parameters.set_userinfo.password = NULL;
-	req.parameters.set_userinfo.user_id = g_strdup(user->username);
-	req.parameters.set_userinfo.pilot_id = user->userID;
-	req.parameters.set_userinfo.continue_sync = continue_sync;
+
+	result = gpc_queue_store_set_userinfo_request (survival==GNOME_Pilot_PERSISTENT?0:timeout,
+						       cradle,
+						       client_id,
+						       user->username,
+						       user->userID,
+						       continue_sync);
 
 	g_free(client_id);
 
-	return gpc_queue_store_request(req);
+	return result;
 }
 
 #if 0
 static CORBA_unsigned_long
 gpilotd_corba_set_user_info_if_not_set(GNOME_Pilot_Daemon obj,
-				       GNOME_Pilot_PilotUser *user,
+				       GNOME_Pilot_UserInfo *user,
 				       const GNOME_Pilot_Client cb,
 				       const CORBA_char *cradle, 
 				       const GNOME_Pilot_Survival survival,
@@ -1161,7 +1186,7 @@ gpilotd_get_pilot_base_dir(PortableServer_Servant _servant,
 		     CORBA_char * pilot_name, 
 		     CORBA_Environment * ev) {
 	int i;
-	LOG("corba: get_pilot_base_dir(id=%s:",pilot_name);
+	LOG("corba: get_pilot_base_dir(id=%s)",pilot_name);
 	
 
 	/* FIXME: this could probably be prettyfied with some _foreach thingies... */
@@ -1319,6 +1344,7 @@ PortableServer_ServantBase__epv base_epv = {
 POA_GNOME_Pilot_Daemon__epv daemon_epv = { 
 	NULL, 
 	(gpointer)&gpilotd_corba_pause,
+	(gpointer)&gpilotd_corba_noop,
 	(gpointer)&gpilotd_corba_request_install,
 	(gpointer)&gpilotd_corba_request_restore,
 	(gpointer)&gpilotd_corba_request_conduit,
@@ -1477,7 +1503,7 @@ void
 orbed_notify_connect(const gchar *pilot_id, 
 		     struct PilotUser user_info) 
 {
-	GNOME_Pilot_PilotUser user_info_orbed;
+	GNOME_Pilot_UserInfo user_info_orbed;
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 
@@ -1610,7 +1636,7 @@ void
 orbed_notify_userinfo(struct PilotUser user_info,
 		      GPilotRequest **req) 
 {
-	GNOME_Pilot_PilotUser user;
+	GNOME_Pilot_UserInfo user;
 	GNOME_Pilot_Client cb;
 
 	g_return_if_fail(req!=NULL);
@@ -1765,6 +1791,9 @@ orbed_notify_conduit_error(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1793,6 +1822,9 @@ orbed_notify_conduit_message(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1818,6 +1850,9 @@ orbed_notify_daemon_message(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1842,6 +1877,9 @@ orbed_notify_daemon_error (gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1867,6 +1905,9 @@ orbed_notify_conduit_progress(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (conduit);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1893,6 +1934,8 @@ orbed_notify_overall_progress(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1995,17 +2038,6 @@ gpilotd_corba_quit(void)
 	CORBA_ORB_shutdown(orb, CORBA_FALSE, &ev);
 }
 
-#ifdef USING_OAF
-static ORBit_MessageValidationResult
-accept_all_cookies (CORBA_unsigned_long request_id,
-		    CORBA_Principal *principal,
-		    CORBA_char *operation)
-{
-        /* allow ALL cookies */
-	return ORBIT_MESSAGE_ALLOW_ALL;
-}
-#endif
-
 void gpilotd_corba_init(int *argc, 
 			char **argv,
 			GPilotContext **context)
@@ -2014,24 +2046,15 @@ void gpilotd_corba_init(int *argc,
 	PortableServer_POA the_poa;
 	GNOME_Pilot_Daemon acc;
 	static gboolean object_initialised = FALSE;
-#ifdef USING_OAF
-	OAF_RegistrationResult result;
-#endif
+	Bonobo_RegistrationResult result;
+
 	if ( object_initialised ) return;
 
 	object_initialised = TRUE;
 
 	CORBA_exception_init(&ev);
 
-#ifdef USING_OAF
-	orb = oaf_init (*argc, argv);
-	ORBit_set_request_validation_handler (accept_all_cookies);
-#else
-	orb = gnome_CORBA_init(PACKAGE,VERSION,
-			       argc,argv,
-			       GNORBA_INIT_SERVER_FUNC,&ev);
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
-#endif
+	orb = bonobo_activation_orb_get();
 
 	*context = gpilot_context_new();
 	gpilot_context_init_user (*context);
@@ -2052,55 +2075,33 @@ void gpilotd_corba_init(int *argc,
 	acc = PortableServer_POA_servant_to_reference(the_poa, &daemon_servant, &ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-	g_message ("Activating server");
-#ifdef USING_OAF
-	result = oaf_active_server_register (
-              "OAFIID:gpilotd:a40c417b-21db-4959-a58e-40096a0daf09",
-	      CORBA_OBJECT (acc));
-	g_message ("oaf_active_server_register = %d", result);
+	g_message ("Activating CORBA server");
+
+	result = bonobo_activation_active_server_register (
+		"OAFIID:GNOME_Pilot_Daemon", acc);
+	g_message ("bonobo_activation_active_server_register = %d", result);
 	switch (result) {
-	case OAF_REG_SUCCESS:
+	case Bonobo_ACTIVATION_REG_SUCCESS:
 		break;
-	case OAF_REG_NOT_LISTED:
+	case Bonobo_ACTIVATION_REG_NOT_LISTED:
 		g_message ("Cannot register gpilotd because not listed");
 		exit (1);
-	case OAF_REG_ALREADY_ACTIVE:
+	case Bonobo_ACTIVATION_REG_ALREADY_ACTIVE:
 		g_message ("Cannot register gpilotd because already active");
 		exit (0);
-	case OAF_REG_ERROR:
+	case Bonobo_ACTIVATION_REG_ERROR:
 	default:
 		g_message ("Cannot register gpilotd because we suck");
 		exit (1);
 	}
-#else 
-	switch(goad_server_register(CORBA_OBJECT_NIL,acc,"gpilotd","object",&ev)) {
-	case -2:
-                /* FIXME: better handling here */
-		g_message(_("The gnome-pilot daemon is already running"));
-		exit (0);
-		break;
-	case -1:
-                /* FIXME: better handling here */
-		g_print("GOAD Name server failure\n");
-		exit (1);
-		break;
-	}
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
-#endif	
 
 	CORBA_Object_release(acc, &ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-	ORBit_custom_run_setup(orb, &ev);
-	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
-
-#ifdef USING_OAF
-	if (!bonobo_init (CORBA_OBJECT_NIL, CORBA_OBJECT_NIL,
-			  CORBA_OBJECT_NIL)) {
+	if (!bonobo_init (argc, argv)) {
 		g_message ("init_bonobo(): could not initialize Bonobo");
 		exit (EXIT_FAILURE);
 	}
-#endif
 }
 
 
